@@ -140,7 +140,7 @@ class StatusView:
                 key = ord(key)
                 if key == 10:  # return
                     break
-                elif key == 127:  # del
+                elif key == 127 or key == 8:  # del
                     if buff:
                         buff = buff[:-1]
                 elif key in (7, 27):  # (^G, <esc>) cancel
@@ -262,7 +262,7 @@ class ChatView:
         msg = chat.get("last_message")
         if (
             msg
-            and self.model.is_me(msg["sender"].get("user_id"))
+            and self.model.is_me(msg["sender_id"].get("user_id"))
             and msg["id"] > chat["last_read_outbox_message_id"]
             and not self.model.is_me(chat["id"])
         ):
@@ -270,7 +270,7 @@ class ChatView:
             flags.append("unseen")
         elif (
             msg
-            and self.model.is_me(msg["sender"].get("user_id"))
+            and self.model.is_me(msg["sender_id"].get("user_id"))
             and msg["id"] <= chat["last_read_outbox_message_id"]
         ):
             flags.append("seen")
@@ -610,7 +610,7 @@ def get_last_msg(
     if not last_msg:
         return None, "<No messages yet>"
     return (
-        last_msg["sender"].get("user_id"),
+        last_msg["sender_id"].get("user_id"),
         parse_content(MsgProxy(last_msg), users),
     )
 
