@@ -175,7 +175,7 @@ class Model:
         return False
 
     def can_be_deleted(self, chat_id: int, msg: Dict[str, Any]) -> bool:
-        c_id = msg["sender"].get("chat_id") or msg["sender"].get("user_id")
+        c_id = msg["sender_id"].get("chat_id") or msg["sender_id"].get("user_id")
         if chat_id == c_id:
             return msg["can_be_deleted_only_for_self"]
         return msg["can_be_deleted_for_all_users"]
@@ -704,6 +704,8 @@ class UserModel:
     def get_status(self, user_id: int) -> str:
         if user_id not in self.users:
             return ""
+        if self.is_bot(user_id):
+            return "bot"
         user_status = self.users[user_id]["status"]
 
         try:
@@ -747,6 +749,12 @@ class UserModel:
         }
         return order.get(status, sys.maxsize)
 
+    def is_bot(self, user_id: int) -> bool:
+        user = self.get_user(user_id)
+        if user and user["type"]["@type"] == "userTypeBot":
+            return True
+        return False
+
     def is_online(self, user_id: int) -> bool:
         user = self.get_user(user_id)
         if (
